Sketch
======

.. currentmodule:: pysylph

Sketch
------

.. autoclass:: pysylph.Sketch
   :special-members: __init__
   :inherited-members:
   :members:



GenomeSketch
------------

.. autoclass:: pysylph.GenomeSketch
   :special-members: __init__
   :inherited-members:
   :members:


SampleSketch
------------

.. autoclass:: pysylph.SampleSketch
   :special-members: __init__
   :inherited-members:
   :members:


